<template>
  <j-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >

    <a-spin :spinning="confirmLoading">
      <a-form-model
        ref="form"
        :model="model"
        :rules="validatorRules"
      >

        <a-form-model-item
          :labelCol="labelCol"
          :wrapperCol="wrapperCol"
          prop="scrapCode"
          label="报废单号"
        >
          <a-input
            placeholder="请输入报废单号"
            v-model="model.scrapCode"
            :disabled="true"
          />
        </a-form-model-item>
        <a-form-model-item
          :labelCol="labelCol"
          :wrapperCol="wrapperCol"
          prop="sparePartsId"
          label="备件信息"
        >
          <j-dict-select-tag
            allow-clear
            :disabled="false"
            placeholder="请选择备件信息"
            :triggerChange="true"
            dictCode="eam_spare_parts,part_name,id, del_flag!='1'"
            v-model="model.sparePartsId"
          />
        </a-form-model-item>

        <a-form-model-item
          :labelCol="labelCol"
          :wrapperCol="wrapperCol"
          prop="scrapNum"
          label="报废数量"
        >
          <a-input-number
            style="width: 100%"
            :min="1"
            :max="999999"
            placeholder="请输入报废数量"
            v-model="model.scrapNum"
          />
        </a-form-model-item>
        <a-form-model-item
          :labelCol="labelCol"
          :wrapperCol="wrapperCol"
          prop="scrapReason"
          label="报废原因"
        >
          <a-textarea
            placeholder="请输入报废原因"
            v-model="model.scrapReason"
          />
        </a-form-model-item>

      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { getAction, httpAction } from '@api/manage'
import moment from "moment"

export default {
  name: "EamSparePartScrapModal",
  data() {
    return {
      title: "操作",
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },

      confirmLoading: false,
      validatorRules: {
        sparePartsId: [
          { required: true, message: '请选择备件' }
        ],
        scrapNum: [
          { required: true, message: '请输入报废数量' }
        ],
        scrapReason: [
          { required: true, message: '请输入报废原因' }
        ]
      },
      url: {
        add: "/eam/eamSparePartScrap/add",
        edit: "/eam/eamSparePartScrap/edit",
        generateRequisitionCode: "sys/sysBusinessCodeRule/generateBusinessCodeSeq"
      },
    }
  },
  created() {
  },
  methods: {
    add() {
      const that = this
      let params = {
        businessCode: "SparePartScrapCodeRule"
      }
      getAction(that.url.generateRequisitionCode, params).then((res) => {
        if (res.success) {
          this.model = {
            scrapCode: res.result
          }
        } else {
          that.$message.warning(res.message);
        }
      })
      //初始化默认值
      that.edit(this.model);
    },
    edit(record) {
      this.model = Object.assign({}, record);
      this.visible = true;
    },
    close() {
      this.$emit('close');
      this.visible = false;
      this.$refs.form.clearValidate();
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        } else {
          return false;
        }
      })
    },
    handleCancel() {
      this.close()
    },


  }
}
</script>

<style lang="less" scoped>
</style>